@@ -11,7 +11,7 @@ class FileIO(ABC):
             storage_type = kw['storage_type'].lower()
         elif len(args) > 0:
             storage_type = args[0]
-        elif get_argument("webHdfsUrl") is not None:
+        elif get_argument("hdfsUrl") is not None:
             storage_type = "hdfs"
         else:
             storage_type = "filesystem"
@@ -34,4 +34,7 @@ class FileIO(ABC):
     @abstractmethod
     def download(self, remote_path, local_path):
         pass
-
+    
+    @abstractmethod
+    def get_modification_time(self, path):
+        pass
